==> ejc-ztpcdc-impl-3.0.0-20230505.055326-10-sources.jar: com/ejianc/business/dc/bean/DcDrawrecycleInfoEntity.java <==
package com.ejianc.business.dc.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;

/**
 * 图纸回收
 *
 * @author generator
 */
@TableName("dc_drawrecycle_info")
public class DcDrawrecycleInfoEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value = "drwgrp_code")
    private String drwgrpCode; // 卷册编号
    @TableField(value = "drwgrp_name")
    private String drwgrpName; // 卷册名称
    @TableField(value = "drwgrp_vsn")
    private String drwgrpVsn; // 卷册版本
    @TableField(value = "drwgrp_type")
    private Long drwgrpType; // 图纸类别--字典dc_drwgrp_type
    @TableField(value = "source_unitid")
    private Long sourceUnitid; // 来源单位id
    @TableField(value = "source_unitname")
    private String sourceUnitname; // 来源单位名称
    @TableField(value = "mgrp")
    private Long mgrp; // 机组--字典pub_mgrp_code
    @TableField(value = "specialty")
    private Long specialty; // 专业--字典pub_specialty_code
    @TableField(value = "sys")
    private Long sys; // 系统--字典pub_system_code
    @TableField(value = "draw_arrive_date")
    private Date drawArriveDate; // 到图日期
    @TableField(value = "issue_user_code")
    private String issueUserCode; // 签发人编号
    @TableField(value = "issue_user_name")
    private String issueUserName; // 签发人姓名
    @TableField(value = "issue_date")
    private Date issueDate; // 签发日期
    @TableField(value = "recycle_code")
    private String recycleCode; // 回收单号
    @TableField(value = "recycle_user_code")
    private String recycleUserCode; // 回收人编号
    @TableField(value = "recycle_user_name")
    private String recycleUserName; // 回收人姓名
    @TableField(value = "recycle_date")
    private Date recycleDate; // 回收日期
    @TableField(value = "create_dept_id")
    private Long createDeptId; // 创建部门id
    @TableField(value = "org_id")
    private Long orgId; // 所属组织id
    @TableField(value = "org_code")
    private String orgCode; // 组织编码
    @TableField(value = "org_name")
    private String orgName; // 组织名称
    @TableField(value = "parent_org_id")
    private Long parentOrgId; // 所属组织
    @TableField(value = "parent_org_code")
    private String parentOrgCode; // 所属组织编码
    @TableField(value = "parent_org_name")
    private String parentOrgName; // 所属组织名称

    @TableField(exist = false)
    @SubEntity(serviceName = "dcDrawrecycleDrwgrpinfoServiceImpl")
    private List<DcDrawrecycleDrwgrpinfoEntity> dcDrawrecycleDrwgrpinfoList = new ArrayList<>();

    @TableField(exist = false)
    private List<DcDrawInfoEntity> dcDrawInfoList = new ArrayList<>();

    public List<DcDrawrecycleDrwgrpinfoEntity> getDcDrawrecycleDrwgrpinfoList() {
        return dcDrawrecycleDrwgrpinfoList;
    }

    public void setDcDrawrecycleDrwgrpinfoList(List<DcDrawrecycleDrwgrpinfoEntity> dcDrawrecycleDrwgrpinfoList) {
        this.dcDrawrecycleDrwgrpinfoList = dcDrawrecycleDrwgrpinfoList;
    }

    public List<DcDrawInfoEntity> getDcDrawInfoList() {
        return dcDrawInfoList;
    }

    public void setDcDrawInfoList(List<DcDrawInfoEntity> dcDrawInfoList) {
        this.dcDrawInfoList = dcDrawInfoList;
    }

    public String getDrwgrpCode() {
        return drwgrpCode;
    }

    public void setDrwgrpCode(String drwgrpCode) {
        this.drwgrpCode = drwgrpCode;
    }

    public String getDrwgrpName() {
        return drwgrpName;
    }

    public void setDrwgrpName(String drwgrpName) {
        this.drwgrpName = drwgrpName;
    }

    public String getDrwgrpVsn() {
        return drwgrpVsn;
    }

    public void setDrwgrpVsn(String drwgrpVsn) {
        this.drwgrpVsn = drwgrpVsn;
    }

    public Long getDrwgrpType() {
        return drwgrpType;
    }

    public void setDrwgrpType(Long drwgrpType) {
        this.drwgrpType = drwgrpType;
    }

    public Long getSourceUnitid() {
        return sourceUnitid;
    }

    public void setSourceUnitid(Long sourceUnitid) {
        this.sourceUnitid = sourceUnitid;
    }

    public String getSourceUnitname() {
        return sourceUnitname;
    }

    public void setSourceUnitname(String sourceUnitname) {
        this.sourceUnitname = sourceUnitname;
    }

    public Long getMgrp() {
        return mgrp;
    }

    public void setMgrp(Long mgrp) {
        this.mgrp = mgrp;
    }

    public Long getSpecialty() {
        return specialty;
    }

    public void setSpecialty(Long specialty) {
        this.specialty = specialty;
    }

    public Long getSys() {
        return sys;
    }

    public void setSys(Long sys) {
        this.sys = sys;
    }

    public Date getDrawArriveDate() {
        return drawArriveDate;
    }

    public void setDrawArriveDate(Date drawArriveDate) {
        this.drawArriveDate = drawArriveDate;
    }

    public String getIssueUserCode() {
        return issueUserCode;
    }

    public void setIssueUserCode(String issueUserCode) {
        this.issueUserCode = issueUserCode;
    }

    public String getIssueUserName() {
        return issueUserName;
    }

    public void setIssueUserName(String issueUserName) {
        this.issueUserName = issueUserName;
    }

    public Date getIssueDate() {
        return issueDate;
    }

    public void setIssueDate(Date issueDate) {
        this.issueDate = issueDate;
    }

    public String getRecycleCode() {
        return recycleCode;
    }

    public void setRecycleCode(String recycleCode) {
        this.recycleCode = recycleCode;
    }

    public String getRecycleUserCode() {
        return recycleUserCode;
    }

    public void setRecycleUserCode(String recycleUserCode) {
        this.recycleUserCode = recycleUserCode;
    }

    public String getRecycleUserName() {
        return recycleUserName;
    }

    public void setRecycleUserName(String recycleUserName) {
        this.recycleUserName = recycleUserName;
    }

    public Date getRecycleDate() {
        return recycleDate;
    }

    public void setRecycleDate(Date recycleDate) {
        this.recycleDate = recycleDate;
    }

    public Long getCreateDeptId() {
        return createDeptId;
    }

    public void setCreateDeptId(Long createDeptId) {
        this.createDeptId = createDeptId;
    }

    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }

    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }

    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }

    public Long getParentOrgId() {
        return parentOrgId;
    }

    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }

    public String getParentOrgCode() {
        return parentOrgCode;
    }

    public void setParentOrgCode(String parentOrgCode) {
        this.parentOrgCode = parentOrgCode;
    }

    public String getParentOrgName() {
        return parentOrgName;
    }

    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }

}

==> ejc-ztpcdc-impl-3.0.0-20230531.020113-32-sources.jar: com/ejianc/business/dc/bean/DcDrawrecycleInfoEntity.java <==
package com.ejianc.business.dc.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;

/**
 * 图纸回收
 *
 * @author generator
 */
@TableName("dc_drawrecycle_info")
public class DcDrawrecycleInfoEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value="bill_state")
    private Integer billState; // 单据状态
    @TableField(value = "drwgrp_code")
    private String drwgrpCode; // 卷册编号
    @TableField(value = "drwgrp_name")
    private String drwgrpName; // 卷册名称
    @TableField(value = "drwgrp_vsn")
    private String drwgrpVsn; // 卷册版本
    @TableField(value = "drwgrp_type")
    private Long drwgrpType; // 图纸类别--字典dc_drwgrp_type
    @TableField(value = "source_unitid")
    private Long sourceUnitid; // 来源单位id
    @TableField(value = "source_unitname")
    private String sourceUnitname; // 来源单位名称
    @TableField(value = "mgrp")
    private Long mgrp; // 机组--字典pub_mgrp_code
    @TableField(value = "specialty")
    private Long specialty; // 专业--字典pub_specialty_code
    @TableField(value = "sys")
    private Long sys; // 系统--字典pub_system_code
    @TableField(value = "draw_arrive_date")
    private Date drawArriveDate; // 到图日期
    @TableField(value = "issue_user_code")
    private String issueUserCode; // 签发人编号
    @TableField(value = "issue_user_name")
    private String issueUserName; // 签发人姓名
    @TableField(value = "issue_date")
    private Date issueDate; // 签发日期
    @TableField(value = "recycle_sts")
    private String recycleSts; // 回收状态（Y已回收/N未回收）
    @TableField(value = "recycle_code")
    private String recycleCode; // 回收单号
    @TableField(value = "recycle_user_code")
    private String recycleUserCode; // 回收人编号
    @TableField(value = "recycle_user_name")
    private String recycleUserName; // 回收人姓名
    @TableField(value = "recycle_date")
    private Date recycleDate; // 回收日期
    @TableField(value = "create_dept_id")
    private Long createDeptId; // 创建部门id
    @TableField(value = "project_id")
    private Long projectId; // 项目ID
    @TableField(value = "project_code")
    private String projectCode; // 项目编码
    @TableField(value = "project_name")
    private String projectName; // 项目名称
    @TableField(value = "org_id")
    private Long orgId; // 所属组织id
    @TableField(value = "org_code")
    private String orgCode; // 组织编码
    @TableField(value = "org_name")
    private String orgName; // 组织名称
    @TableField(value = "parent_org_id")
    private Long parentOrgId; // 所属组织
    @TableField(value = "parent_org_code")
    private String parentOrgCode; // 所属组织编码
    @TableField(value = "parent_org_name")
    private String parentOrgName; // 所属组织名称

    @TableField(exist = false)
    @SubEntity(serviceName = "dcDrawrecycleDrwgrpinfoService")
    private List<DcDrawrecycleDrwgrpinfoEntity> dcDrawrecycleDrwgrpinfoList = new ArrayList<>();

    @TableField(exist = false)
    private List<DcDrawInfoEntity> dcDrawInfoList = new ArrayList<>();

    public List<DcDrawrecycleDrwgrpinfoEntity> getDcDrawrecycleDrwgrpinfoList() {
        return dcDrawrecycleDrwgrpinfoList;
    }

    public void setDcDrawrecycleDrwgrpinfoList(List<DcDrawrecycleDrwgrpinfoEntity> dcDrawrecycleDrwgrpinfoList) {
        this.dcDrawrecycleDrwgrpinfoList = dcDrawrecycleDrwgrpinfoList;
    }

    public List<DcDrawInfoEntity> getDcDrawInfoList() {
        return dcDrawInfoList;
    }

    public void setDcDrawInfoList(List<DcDrawInfoEntity> dcDrawInfoList) {
        this.dcDrawInfoList = dcDrawInfoList;
    }

    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }

    public String getDrwgrpCode() {
        return drwgrpCode;
    }

    public void setDrwgrpCode(String drwgrpCode) {
        this.drwgrpCode = drwgrpCode;
    }

    public String getDrwgrpName() {
        return drwgrpName;
    }

    public void setDrwgrpName(String drwgrpName) {
        this.drwgrpName = drwgrpName;
    }

    public String getDrwgrpVsn() {
        return drwgrpVsn;
    }

    public void setDrwgrpVsn(String drwgrpVsn) {
        this.drwgrpVsn = drwgrpVsn;
    }

    public Long getDrwgrpType() {
        return drwgrpType;
    }

    public void setDrwgrpType(Long drwgrpType) {
        this.drwgrpType = drwgrpType;
    }

    public Long getSourceUnitid() {
        return sourceUnitid;
    }

    public void setSourceUnitid(Long sourceUnitid) {
        this.sourceUnitid = sourceUnitid;
    }

    public String getSourceUnitname() {
        return sourceUnitname;
    }

    public void setSourceUnitname(String sourceUnitname) {
        this.sourceUnitname = sourceUnitname;
    }

    public Long getMgrp() {
        return mgrp;
    }

    public void setMgrp(Long mgrp) {
        this.mgrp = mgrp;
    }

    public Long getSpecialty() {
        return specialty;
    }

    public void setSpecialty(Long specialty) {
        this.specialty = specialty;
    }

    public Long getSys() {
        return sys;
    }

    public void setSys(Long sys) {
        this.sys = sys;
    }

    public Date getDrawArriveDate() {
        return drawArriveDate;
    }

    public void setDrawArriveDate(Date drawArriveDate) {
        this.drawArriveDate = drawArriveDate;
    }

    public String getIssueUserCode() {
        return issueUserCode;
    }

    public void setIssueUserCode(String issueUserCode) {
        this.issueUserCode = issueUserCode;
    }

    public String getIssueUserName() {
        return issueUserName;
    }

    public void setIssueUserName(String issueUserName) {
        this.issueUserName = issueUserName;
    }

    public Date getIssueDate() {
        return issueDate;
    }

    public void setIssueDate(Date issueDate) {
        this.issueDate = issueDate;
    }

    public String getRecycleSts() {
        return recycleSts;
    }

    public void setRecycleSts(String recycleSts) {
        this.recycleSts = recycleSts;
    }

    public String getRecycleCode() {
        return recycleCode;
    }

    public void setRecycleCode(String recycleCode) {
        this.recycleCode = recycleCode;
    }

    public String getRecycleUserCode() {
        return recycleUserCode;
    }

    public void setRecycleUserCode(String recycleUserCode) {
        this.recycleUserCode = recycleUserCode;
    }

    public String getRecycleUserName() {
        return recycleUserName;
    }

    public void setRecycleUserName(String recycleUserName) {
        this.recycleUserName = recycleUserName;
    }

    public Date getRecycleDate() {
        return recycleDate;
    }

    public void setRecycleDate(Date recycleDate) {
        this.recycleDate = recycleDate;
    }

    public Long getCreateDeptId() {
        return createDeptId;
    }

    public void setCreateDeptId(Long createDeptId) {
        this.createDeptId = createDeptId;
    }

    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }

    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }

    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }

    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }

    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }

    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }

    public Long getParentOrgId() {
        return parentOrgId;
    }

    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }

    public String getParentOrgCode() {
        return parentOrgCode;
    }

    public void setParentOrgCode(String parentOrgCode) {
        this.parentOrgCode = parentOrgCode;
    }

    public String getParentOrgName() {
        return parentOrgName;
    }

    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }

}
